@@ -1,8 +1,10 @@
 # flake8: noqa
+from .args import *
 from .distance import *
 from .match import *
 from .ratio import *
+from .scorer import *
 from .strings import *
 
 __title__ = "stringmatch"
-__version__ = "0.7.0"
+__version__ = "0.11.0"
